<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfStatisticsTracker.php 1239 2005-01-17 17:39:11Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once maintenancePath . '/libraries/max/Dal/StatisticsTracker.php';

/**
 * A class for testing the Dal_Statistics_Tracker class.
 */
class Dal_TestOfStatisticsTracker extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Dal_TestOfStatisticsTracker()
    {
        $this->UnitTestCase();
    }
    
    /**
     * Tests that the singleton() method only ever returns one class instance.
     */
    function testSingleton()
    {
        debug('Running test', PEAR_LOG_INFO);
        $first =& Dal_Statistics_Tracker::singleton();
        $second =& Dal_Statistics_Tracker::singleton();
        $this->assertIdentical($first, $second);
    }
    
    /**
     * Tests the getMaintenanceStatisticsLastRunInfo() method.
     */
    function testGetMaintenanceStatisticsLastRunInfo()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 60;
        $conf['table']['split'] = false;
        $dsa =& Dal_Statistics_Tracker::singleton();
        // Create the required tables
        $dsa->tables->createTable('data_raw_tracker_impression');
        $dsa->tables->createTable('log_maintenance_statistics');
        // Test with no data
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertNull($date);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertNull($date);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsTracker.php';
        // Insert tracker impressions
        $dsa->execute(TOT_DATA_RAW_TRACKER_IMPRESSIONS, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-05-06 11:59:59'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-05-06 11:59:59'));
        // Insert an hourly (only) update
        $dsa->execute(TOT_LMS_HOUR, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-05-06 11:59:59'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert an operation interval (only) update
        $dsa->execute(TOT_LMS_OI, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-06-06 10:16:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert a dual interval update
        $dsa->execute(TOT_LMS_DUAL, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression']);
        $dsa->tables->dropTable($conf['table']['log_maintenance_statistics']);
    }
    
    /**
     * Tests the deleteOldData() method.
     */
    function testDeleteOldData()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['compact_stats_grace'] = 0;
        $dsa =& Dal_Statistics_Tracker::singleton();
        // Create the required tables
        $dsa->tables->createTable('data_raw_tracker_click');
        $dsa->tables->createTable('data_raw_tracker_impression');
        $dsa->tables->createTable('data_raw_tracker_variable_value');
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsTracker.php';
        // Insert the test data
        $dsa->execute(TOT_DELETE_OLD_DATA_TRACKER_CLICKS, $result);
        $dsa->execute(TOT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS, $result);
        $dsa->execute(TOT_DELETE_OLD_DATA_TRACKER_VARIABLE_VALUES, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_click']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_impression']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_variable_value']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        // Set a compact_stats_grace window
        $conf['maintenance']['compact_stats_grace'] = 3600;
        // Drop and re-create the raw tables
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_click']);
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression']);
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_variable_value']);
        $dsa->tables->createTable('data_raw_tracker_click');
        $dsa->tables->createTable('data_raw_tracker_impression');
        $dsa->tables->createTable('data_raw_tracker_variable_value');
        // Re-insert the test data
        $dsa->execute(TOT_DELETE_OLD_DATA_TRACKER_CLICKS, $result);
        $dsa->execute(TOT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS, $result);
        $dsa->execute(TOT_DELETE_OLD_DATA_TRACKER_VARIABLE_VALUES, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_click']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_impression']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_tracker_variable_value']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
    }

    /**
     * Tests the logCompletion() method.
     */
    function testLogCompletion()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dsa =& Dal_Statistics_Tracker::singleton();
        // Create the required tables
        $dsa->tables->createTable('log_maintenance_statistics');
        $dsa->tables->createTable('userlog');
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:01:05');
        $report = 'Report Text';
        $dsa->logCompletion($start, $end, 0, $start, $report);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                tracker_run_type = 0";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                tracker_run_type = 0";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['start_run'], '2004-06-06 18:00:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:01:05');
        $this->assertEqual($row['duration'], 65);
        $this->assertEqual($row['updated_to'], '2004-06-06 18:00:00');
        $start = new Date('2004-06-06 19:00:00');
        $end = new Date('2004-06-06 19:00:05');
        $dsa->logCompletion($start, $end, 1, $start, $report);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                tracker_run_type = 1";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                tracker_run_type = 1";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['start_run'], '2004-06-06 19:00:00');
        $this->assertEqual($row['end_run'], '2004-06-06 19:00:05');
        $this->assertEqual($row['duration'], 5);
        $this->assertEqual($row['updated_to'], '2004-06-06 19:00:00');
        $start = new Date('2004-06-06 20:00:00');
        $end = new Date('2004-06-06 21:00:05');
        $dsa->logCompletion($start, $end, 2, $start, $report);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                tracker_run_type = 2";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                tracker_run_type = 2";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['start_run'], '2004-06-06 20:00:00');
        $this->assertEqual($row['end_run'], '2004-06-06 21:00:05');
        $this->assertEqual($row['duration'], 3605);
        $this->assertEqual($row['updated_to'], '2004-06-06 20:00:00');
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['log_maintenance_statistics']);
        $dsa->tables->dropTable($conf['table']['userlog']);
    }
    
}

?>
